==> mimR_1.1.5.tar.gz: mimR/R/base.R <==
require(MASS)

.First.lib <- function(lib, pkg)
{
  if((R.version$major == 1) && (as.numeric(R.version$minor) < 9)) 
        packageDescription <- package.description 
  cat("\n")
  cat("-------------------------------------------------------------\n")
  cat(package.description("mimR", lib = lib, field="Title"))
  cat("\n")
  ver  <- package.description("mimR", lib = lib, field="Version")
  maint<- package.description("mimR", lib = lib, field="Maintainer")
  built<- package.description("mimR", lib = lib, field="Built")
  URL  <- package.description("mimR", lib = lib, field="URL")
  cat(paste("mimR, version", ver,  "is now loaded\n"))
  cat("Copyright (C) 2002, Sren Hjsgaard\n")
  cat("Maintained by",maint,"\n")
  cat("Webpage:",URL,"\n")
  cat("\nBuilt:",built,"\n")
  cat("NOTICE:\n")
  cat("o mimR is available on Windows platforms only \n")
  cat("o To use mimR the MIM program must be running\n")
  cat("o The current version of mimR requires MIM version 3.1.3.3 or later\n")
  cat("o MIM is available from http://www.hypergraph.dk.\n")
  cat("o The current version of mimR requires R version 1.8.1 or later\n")
  #cat("\n  For a demo of mimR, type demo(mimR)\n")
  cat("-------------------------------------------------------------\n")
  return(invisible(0))
}

.Last.lib <- function(lib) {
  cat("Thank you for using mimR\n")
  return(invisible(0))
}

mim.cmd <- function(cmd, look.nice = TRUE, return.look.nice=FALSE, version='R') {
  if (!is.character(cmd)) stop("invalid input")
  outLines <- character(0)
  if (version=='R') {
    MIM <- socketConnection(port=50) 
    for (i in 1:length(cmd)) {
      theseLines <- character(0)
      writeLines(cmd[i], MIM, sep='')
      repeat {
        theseLines <- c(theseLines, readLines(MIM))
        if (length(theseLines) == 0) next
        if (theseLines[length(theseLines)] == 'COMPLETE') break }
      outLines <- c(outLines, theseLines[-length(theseLines)])
      if (look.nice==TRUE)    
        sapply(outLines,function(x) cat(x, fill=TRUE))
      if (return.look.nice==TRUE){
        value <- outLines
      }
      else{
        str2 <- paste(outLines, collapse = " ")
        value <- unlist(strsplit(str2, " +"))
        value <- value[value!=""]    
      }
    }
    close(MIM)
    return( invisible(value) );
  } else {
    MIM <- create.ole.object("mim31.Server")
    for (i in 1:length(cmd)) {
      NoOutputLines <- call.ole.method(MIM, "SendCmdLine", cmd[i]) 
      for (i in 1:NoOutputLines)
        outLines <- c(outLines,
                      call.ole.method(MIM, "GetOutputLine")) }
    release.ole.object(MIM)
    return(outLines)
  }
}  

mcm <- function(){
  cat("Enter MIM commands here. Type quit to return to R\n")
  x <- readline("MIM->")
  while(length(which(c("stop","end","quit","exit","e","q")==x))==0){
    mim.out <- mim.cmd(x,look.nice=TRUE)
    x <- readline("MIM->")
  }
}


.mim.cmd.term <- function(mim.cmds, look.nice = TRUE, return.look.nice=FALSE){

  .split.mim.input <- function(input,token=NULL){
    s<-strsplit(input,'')[[1]]
    res <- NULL
    len <- 80
    while(length(s)>len){
      s1 <- s[1:len]
      res <- c(res, paste(paste(s1,collapse=''),token))
      s  <- s[-(1:len)]
    }
    value <- c(res, paste(s,collapse=''))
    return(value)
  }

  .call.mim.MIMterm  <- function(cmd.str){
    ##cat("Communicating with MIM engine. This may take a moment... ")
    tmp <- proc.time()
    mimR.dir <- system.file(package="mimR")
    cmd.str  <- paste(mimR.dir,'/MIMterm/MIMterm.exe "', cmd.str, '"',sep='')
    value    <- system(cmd.str, show.output.on.console=FALSE, invisible=TRUE,
                       intern=TRUE)
    ##cat("Time taken:", round((proc.time()-tmp)[3],2),"sec\n")
    return(value)
  }
  if (nchar(mim.cmds)>80)
    mim.cmds <- .split.mim.input(mim.cmds,token='&')
  
  v<- lapply(mim.cmds, function(a){
    v  <- .call.mim.MIMterm(a);
    return(v)
  })
  v<- v[[length(v)]]
  if (look.nice==TRUE)    
    sapply(v,function(x) cat(x, fill=TRUE))
  if (return.look.nice==TRUE){
    value <- v
  }
  else{
    str2 <- paste(v, collapse = " ")
    value <- unlist(strsplit(str2, " +"))
    value <- value[value!=""]    
  }
  return( invisible(value) );
}

.mim.cmd.file <- function(mim.cmds){
  file     <- paste(getwd(),"\\","mimCMD.txt",sep='')
  write("%\n% COMMAND FILE GENERATED BY mimR", file, append=FALSE)
  lapply(mim.cmds, write, file,append=TRUE)
  mim.cmd(paste("input",file))
}

==> mimR_1.2.tar.gz: mimR/R/base.R <==
require(MASS)

.First.lib <- function(lib, pkg)
{
  if((R.version$major == 1) && (as.numeric(R.version$minor) < 9)) 
        packageDescription <- package.description 
  cat("\n")
  cat("-------------------------------------------------------------\n")
  cat(packageDescription("mimR", lib = lib, field="Title"))
  cat("\n")
  ver  <- packageDescription("mimR", lib = lib, field="Version")
  maint<- packageDescription("mimR", lib = lib, field="Maintainer")
  built<- packageDescription("mimR", lib = lib, field="Built")
  URL  <- packageDescription("mimR", lib = lib, field="URL")
  cat(paste("mimR, version", ver,  "is now loaded\n"))
  cat("Copyright (C) 2002, Sren Hjsgaard\n")
  cat("Maintained by",maint,"\n")
  cat("Webpage:",URL,"\n")
  cat("\nBuilt:",built,"\n")
  cat("NOTICE:\n")
  cat("o mimR is available on Windows platforms only \n")
  cat("o To use mimR the MIM program must be running\n")
  cat("o The current version of mimR requires MIM version 3.1.3.3 or later\n")
  cat("o MIM is available from http://www.hypergraph.dk.\n")
  cat("o The current version of mimR requires R version 1.8.1 or later\n")
  #cat("\n  For a demo of mimR, type demo(mimR)\n")
  cat("-------------------------------------------------------------\n")
  return(invisible(0))
}

.Last.lib <- function(lib) {
  cat("Thank you for using mimR\n")
  return(invisible(0))
}

mim.cmd <- function(cmd, look.nice = TRUE, return.look.nice=FALSE, version='R') {
  if (!is.character(cmd)) stop("invalid input")
  outLines <- character(0)
  if (version=='R') {
    MIM <- socketConnection(port=50) 
    for (i in 1:length(cmd)) {
      theseLines <- character(0)
      writeLines(cmd[i], MIM, sep='')
      repeat {
        theseLines <- c(theseLines, readLines(MIM))
        if (length(theseLines) == 0) next
        if (theseLines[length(theseLines)] == 'COMPLETE') break }
      outLines <- c(outLines, theseLines[-length(theseLines)])
      if (look.nice==TRUE)    
        sapply(outLines,function(x) cat(x, fill=TRUE))
      if (return.look.nice==TRUE){
        value <- outLines
      }
      else{
        str2 <- paste(outLines, collapse = " ")
        value <- unlist(strsplit(str2, " +"))
        value <- value[value!=""]    
      }
    }
    close(MIM)
    return( invisible(value) );
  } else {
    MIM <- create.ole.object("mim31.Server")
    for (i in 1:length(cmd)) {
      NoOutputLines <- call.ole.method(MIM, "SendCmdLine", cmd[i]) 
      for (i in 1:NoOutputLines)
        outLines <- c(outLines,
                      call.ole.method(MIM, "GetOutputLine")) }
    release.ole.object(MIM)
    return(outLines)
  }
}  

mcm <- function(){
  cat("Enter MIM commands here. Type quit to return to R\n")
  x <- readline("MIM->")
  while(length(which(c("stop","end","quit","exit","e","q")==x))==0){
    mim.out <- mim.cmd(x,look.nice=TRUE)
    x <- readline("MIM->")
  }
}


.mim.cmd.term <- function(mim.cmds, look.nice = TRUE, return.look.nice=FALSE){

  .split.mim.input <- function(input,token=NULL){
    s<-strsplit(input,'')[[1]]
    res <- NULL
    len <- 80
    while(length(s)>len){
      s1 <- s[1:len]
      res <- c(res, paste(paste(s1,collapse=''),token))
      s  <- s[-(1:len)]
    }
    value <- c(res, paste(s,collapse=''))
    return(value)
  }
  
  .call.mim.MIMterm  <- function(cmd.str){
    tmp <- proc.time()
    mimR.dir <- system.file(package="mimR")
    cmd.str  <- paste(mimR.dir,'/MIMterm/MIMterm.exe "', cmd.str, '"',sep='')
    value    <- system(cmd.str, show.output.on.console=FALSE, invisible=TRUE,
                       intern=TRUE)
    return(value)
  }
  if (nchar(mim.cmds)>80)
    mim.cmds <- .split.mim.input(mim.cmds,token='&')
  
  v<- lapply(mim.cmds, function(a){
    v  <- .call.mim.MIMterm(a);
    return(v)
  })
  v<- v[[length(v)]]
  if (look.nice==TRUE)    
    sapply(v,function(x) cat(x, fill=TRUE))
  if (return.look.nice==TRUE){
    value <- v
  }
  else{
    str2 <- paste(v, collapse = " ")
    value <- unlist(strsplit(str2, " +"))
    value <- value[value!=""]    
  }
  return( invisible(value) );
}

.mim.cmd.file <- function(mim.cmds){
  file     <- paste(getwd(),"\\","mimCMD.txt",sep='')
  write("%\n% COMMAND FILE GENERATED BY mimR", file, append=FALSE)
  lapply(mim.cmds, write, file,append=TRUE)
  mim.cmd(paste("input",file))
}
